"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.errorsIgnore = exports.errorsConfig = void 0;
const errorsConfig = {
    'no-array-constructor': 'error',
    'no-async-promise-executor': 'error',
    'no-bitwise': 'error',
    'no-caller': 'error',
    'no-case-declarations': 'off',
    'no-console': [
        'error',
        {
            allow: ['log', 'warn', 'error']
        }
    ],
    'no-const-assign': 'error',
    'no-constant-condition': 'error',
    'no-constructor-return': 'error',
    'no-control-regex': 'error',
    'no-debugger': 'error',
    'no-div-regex': 'off',
    'no-dupe-args': 'error',
    'no-dupe-class-members': 'error',
    'no-dupe-keys': 'error',
    'no-duplicate-case': 'error',
    'no-duplicate-imports': 'off',
    'no-empty': 'error',
    'no-empty-function': [
        'error',
        {
            allow: ['arrowFunctions', 'functions', 'methods']
        }
    ],
    'no-empty-pattern': 'error',
    'no-eq-null': 'off',
    'no-eval': 'error',
    'no-extend-native': 'error',
    'no-extra-bind': 'error',
    'no-extra-label': 'error',
    'no-extra-semi': 'error',
    'no-fallthrough': 'error',
    'no-floating-decimal': 'error',
    'no-global-assign': [
        'error',
        {
            exceptions: []
        }
    ],
    'no-implicit-coercion': [
        'off',
        {
            allow: [],
            boolean: false,
            number: true,
            string: true
        }
    ],
    'no-implicit-globals': 'off',
    'no-implied-eval': 'error',
    'no-invalid-this': 'off',
    'no-irregular-whitespace': 'error',
    'no-iterator': 'error',
    'no-labels': [
        'error',
        {
            allowLoop: false,
            allowSwitch: false
        }
    ],
    'no-lone-blocks': 'error',
    'no-magic-numbers': [
        'off',
        {
            detectObjects: false,
            enforceConst: true,
            ignore: [],
            ignoreArrayIndexes: true
        }
    ],
    'no-mixed-operators': [
        'error',
        {
            allowSamePrecedence: false,
            groups: [
                ['%', '**'],
                ['%', '+'],
                ['%', '-'],
                ['%', '*'],
                ['%', '/'],
                ['/', '*'],
                ['&', '|', '<<', '>>', '>>>'],
                ['==', '!=', '===', '!=='],
                ['&&', '||']
            ]
        }
    ],
    'no-mixed-spaces-and-tabs': 'error',
    'no-multi-spaces': [
        'error',
        {
            ignoreEOLComments: false
        }
    ],
    'no-multiple-empty-lines': [
        'error',
        {
            max: 1,
            maxBOF: 0,
            maxEOF: 1
        }
    ],
    'no-native-reassign': 'off',
    'no-new': 'error',
    'no-new-func': 'error',
    'no-new-object': 'error',
    'no-new-symbol': 'error',
    'no-new-wrappers': 'error',
    'no-octal': 'error',
    'no-octal-escape': 'error',
    'no-proto': 'error',
    'no-prototype-builtins': 'off',
    'no-redeclare': 'error',
    'no-regex-spaces': 'error',
    'no-restricted-properties': [
        'error',
        {
            message: 'arguments.callee is deprecated',
            object: 'arguments',
            property: 'callee'
        },
        {
            message: 'Please use Number.isFinite instead',
            object: 'global',
            property: 'isFinite'
        },
        {
            message: 'Please use Number.isFinite instead',
            object: 'self',
            property: 'isFinite'
        },
        {
            message: 'Please use Number.isFinite instead',
            object: 'window',
            property: 'isFinite'
        },
        {
            message: 'Please use Number.isNaN instead',
            object: 'global',
            property: 'isNaN'
        },
        {
            message: 'Please use Number.isNaN instead',
            object: 'self',
            property: 'isNaN'
        },
        {
            message: 'Please use Number.isNaN instead',
            object: 'window',
            property: 'isNaN'
        },
        {
            message: 'Please use Object.defineProperty instead.',
            property: '__defineGetter__'
        },
        {
            message: 'Please use Object.defineProperty instead.',
            property: '__defineSetter__'
        },
        {
            message: 'Use the exponentiation operator (**) instead.',
            object: 'Math',
            property: 'pow'
        }
    ],
    'no-return-assign': ['error', 'except-parens'],
    'no-return-await': 'error',
    'no-self-assign': [
        'error',
        {
            props: true
        }
    ],
    'no-self-compare': 'error',
    'no-sequences': 'error',
    'no-spaced-func': 'error',
    'no-tabs': 'error',
    'no-throw-literal': 'error',
    'no-trailing-spaces': [
        'error',
        {
            ignoreComments: false,
            skipBlankLines: false
        }
    ],
    'no-undef': 'error',
    'no-undef-init': 'error',
    'no-unexpected-multiline': 'error',
    'no-unmodified-loop-condition': 'off',
    'no-unneeded-ternary': [
        'error',
        {
            defaultAssignment: false
        }
    ],
    'no-unreachable': 'error',
    'no-unsafe-finally': 'error',
    'no-unsafe-negation': 'error',
    'no-unused-labels': 'error',
    'no-unused-vars': [
        'error',
        {
            args: 'after-used',
            ignoreRestSiblings: true,
            vars: 'all'
        }
    ],
    'no-use-before-define': [
        'error',
        {
            classes: true,
            functions: false,
            variables: true
        }
    ],
    'no-useless-call': 'off',
    'no-useless-catch': 'error',
    'no-useless-concat': 'error',
    'no-useless-constructor': 'error',
    'no-useless-escape': 'error',
    'no-useless-return': 'error',
    'no-var': 'error',
    'no-warning-comments': [
        'off',
        {
            location: 'start',
            terms: ['todo', 'fixme', 'xxx']
        }
    ],
    'no-whitespace-before-property': 'error',
    'no-with': 'error'
};
exports.errorsConfig = errorsConfig;
const errorsIgnore = {
    'func-names': 'off',
    'no-console': 'off',
    'no-debugger': 'off',
    'no-empty-function': 'off',
    'no-new': 'off',
    'no-restricted-imports': 'off',
    'no-return-await': 'off',
    'no-throw-literal': 'off',
    'no-undef': 'off'
};
exports.errorsIgnore = errorsIgnore;
