"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.formatterIgnore = exports.formatterConfig = void 0;
const formatterConfig = {
    'array-bracket-spacing': ['error', 'never'],
    'arrow-spacing': [
        'error',
        {
            after: true,
            before: true
        }
    ],
    'block-spacing': ['error', 'always'],
    camelcase: [
        'error',
        {
            ignoreDestructuring: false,
            properties: 'never'
        }
    ],
    'capitalized-comments': [
        'off',
        'never',
        {
            block: {
                ignoreConsecutiveComments: true,
                ignoreInlineComments: true,
                ignorePattern: '.*'
            },
            line: {
                ignoreConsecutiveComments: true,
                ignoreInlineComments: true,
                ignorePattern: '.*'
            }
        }
    ],
    'comma-spacing': [
        'error',
        {
            after: true,
            before: false
        }
    ],
    'comma-style': [
        'error',
        'last',
        {
            exceptions: {
                ArrayExpression: false,
                ArrayPattern: false,
                ArrowFunctionExpression: false,
                CallExpression: false,
                FunctionDeclaration: false,
                FunctionExpression: false,
                ImportDeclaration: false,
                NewExpression: false,
                ObjectExpression: false,
                ObjectPattern: false,
                VariableDeclaration: false
            }
        }
    ],
    'computed-property-spacing': ['error', 'never'],
    curly: ['error', 'multi-line'],
    'dot-location': ['error', 'property'],
    'eol-last': ['error', 'always'],
    'func-call-spacing': ['error', 'never'],
    'func-name-matching': [
        'off',
        'always',
        {
            considerPropertyDescriptor: true,
            includeCommonJSModuleExports: false
        }
    ],
    'func-names': 'warn',
    'key-spacing': [
        'error',
        {
            afterColon: true,
            beforeColon: false
        }
    ],
    'keyword-spacing': [
        'error',
        {
            after: true,
            before: true,
            overrides: {
                case: {
                    after: true
                },
                return: {
                    after: true
                },
                throw: {
                    after: true
                }
            }
        }
    ],
    'line-comment-position': [
        'error',
        {
            applyDefaultPatterns: true,
            position: 'above'
        }
    ],
    'lines-around-comment': 'off',
    'lines-around-directive': [
        'error',
        {
            after: 'always',
            before: 'always'
        }
    ],
    'lines-between-class-members': [
        'error',
        'always',
        {
            exceptAfterSingleLine: false
        }
    ],
    'max-depth': ['off', 4],
    'max-len': [
        'error',
        160,
        4,
        {
            ignoreComments: true,
            ignoreRegExpLiterals: true,
            ignoreStrings: true,
            ignoreTemplateLiterals: true,
            ignoreTrailingComments: false,
            ignoreUrls: true
        }
    ],
    'max-statements-per-line': [
        'error',
        {
            max: 1
        }
    ],
    'multiline-comment-style': ['error', 'separate-lines'],
    'new-parens': 'error',
    'nonblock-statement-body-position': [
        'error',
        'beside',
        {
            overrides: {}
        }
    ],
    'object-curly-newline': [
        'error',
        {
            ExportDeclaration: {
                consistent: true,
                minProperties: 8,
                multiline: true
            },
            ImportDeclaration: {
                consistent: true,
                minProperties: 8,
                multiline: true
            },
            ObjectExpression: {
                consistent: true,
                minProperties: 12,
                multiline: true
            },
            ObjectPattern: {
                consistent: true,
                minProperties: 12,
                multiline: true
            }
        }
    ],
    'object-curly-spacing': ['error', 'always'],
    'padding-line-between-statements': [
        'error',
        {
            blankLine: 'any',
            next: 'return',
            prev: '*'
        },
        {
            blankLine: 'any',
            next: '*',
            prev: ['const', 'let', 'var']
        },
        {
            blankLine: 'any',
            next: ['const', 'let', 'var'],
            prev: ['const', 'let', 'var']
        }
    ],
    'quote-props': [
        'error',
        'as-needed',
        {
            keywords: false,
            numbers: false,
            unnecessary: true
        }
    ],
    quotes: [
        'error',
        'single',
        {
            avoidEscape: true
        }
    ],
    'semi-spacing': [
        'error',
        {
            after: true,
            before: false
        }
    ],
    'semi-style': ['error', 'last'],
    'space-before-blocks': 'error',
    'space-before-function-paren': [
        'error',
        {
            anonymous: 'always',
            asyncArrow: 'always',
            named: 'never'
        }
    ],
    'space-in-parens': ['error', 'never'],
    'space-infix-ops': 'error',
    'space-unary-ops': [
        'error',
        {
            nonwords: false,
            overrides: {},
            words: true
        }
    ],
    'spaced-comment': [
        'error',
        'always',
        {
            block: {
                balanced: true,
                exceptions: ['-', '+'],
                markers: ['=', '!', ':', '::']
            },
            line: {
                exceptions: ['-', '+'],
                markers: ['=', '!', '/']
            }
        }
    ],
    'switch-colon-spacing': [
        'error',
        {
            after: true,
            before: false
        }
    ],
    'template-curly-spacing': 'error',
    'template-tag-spacing': ['error', 'never'],
    'unicode-bom': ['error', 'never']
};
exports.formatterConfig = formatterConfig;
const formatterIgnore = {
    'padding-line-between-statements': 'off'
};
exports.formatterIgnore = formatterIgnore;
